/* ***** BEGIN LICENSE BLOCK *****
 * Licensed	under Version: MPL 1.1/GPL 2.0/LGPL	2.1
 * Full	Terms at http://mozile.mozdev.org/license.html
 *
 * Software	distributed	under the License is distributed on	an "AS IS" basis,
 * WITHOUT WARRANTY	OF ANY KIND, either	express	or implied.	See	the	License
 * for the specific	language governing rights and limitations under	the
 * License.
 *
 * The Original	Code is	Playsophy code.
 *
 * The Initial Developer of	the	Original Code is Playsophy
 * Portions	created	by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		James A. Overton <james@overton.ca>
 *		Andreas	Schamberger	<mozile@andreass.net>
 *		Paul Everitt
 *
 * ***** END LICENSE BLOCK ***** */

//indexes of the drop down menus.
const MOZILE_SAVE_PRESET_PAGE = 0;
const MOZILE_SAVE_PRESET_USER = 1;
const MOZILE_SAVE_PRESET_CUSTOM = 2;

const MOZILE_SAVE_CONTENT_PAGE = 0;
const MOZILE_SAVE_CONTENT_CURRENT = 1;
const MOZILE_SAVE_CONTENT_CURRENT_NS = 2;

const MOZILE_SAVE_METHOD_LOCAL = 0;
const MOZILE_SAVE_METHOD_DISPLAY = 1;
const MOZILE_SAVE_METHOD_POST = 2;
const MOZILE_SAVE_METHOD_WEBDAV = 3;

function MozileSavePresets ( content, method, path ) {
	this.saveContent = content || "page";
	this.saveMethod = method || "display";
	this.httpSavePath = path || "http://";
}
function MozileCurrentSaveSettings () {
	this.preset = "user";
	this.Presets = new MozileSavePresets();
}

var PagePresets = new MozileSavePresets;
var UserPresets = new MozileSavePresets;
var CustomPresets = new MozileSavePresets("none");
var CurrentSettings = new MozileCurrentSaveSettings();

var _mozilePrefs = "";
/*
	Initialize the dialog.
	Initial values when the dialog is opened for the first time will be the defaults
	from mozileConfiguration.js applied when Mozile is injected.
	On subsequent opening of the dialog, the intial values should be the last used values. 
*/
function mozileInit()	
{
	var	f =	["save.js","init"];
	opener.mozileDebug(f,3,"Initializing");

	try{	

		//Get current target, if there is one.
		var	_mozileTarget = opener.mozileGetCurrentTarget();
		opener.mozileDebug(f,3,"Target:	"+_mozileTarget);

		//Get the user presets
		try {
			netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');
			_mozilePrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
			var tempUP = new MozileSavePresets;
			tempUP.saveContent = _mozilePrefs.getCharPref("mozile.saveContentString");
			tempUP.saveMethod = _mozilePrefs.getCharPref("mozile.saveMethodString");
			tempUP.httpSavePath = _mozilePrefs.getCharPref("mozile.saveHttpPathString");
			UserPresets = tempUP;

			if ( !("MOZILE_CUSTOM_CONFIG" in _mozileTarget.document) ) {
				//If opener doesn't have custom presets, create them.
				_mozileTarget.document.MOZILE_CUSTOM_CONFIG = new MozileSavePresets("none");
			} else if ( _mozileTarget.document.MOZILE_CUSTOM_CONFIG.saveContent != "none" ) {
				document.getElementById('mozileCustomPreset').setAttribute( "disabled", "false" );
				CustomPresets = _mozileTarget.document.MOZILE_CUSTOM_CONFIG;
			}		

		} catch (e) {
			opener.mozileDebug(f,3,"Error getting user prefs:	"+e);
		}


		if(_mozileTarget && _mozileTarget!="") {
			if ( "saveContent" in _mozileTarget.document.MOZILE_RSD_CONFIG ) {
				PagePresets.saveContent = _mozileTarget.document.MOZILE_RSD_CONFIG.saveContent;
				PagePresets.saveMethod = _mozileTarget.document.MOZILE_RSD_CONFIG.saveMethod;
				PagePresets.httpSavePath = _mozileTarget.document.MOZILE_RSD_CONFIG.httpSavePath;
				mozileSetLocks( _mozileTarget.document.MOZILE_RSD_CONFIG );
			}

			CurrentSettings.preset = _mozileTarget.document.MOZILE_CURRENT_CONFIG.preset;
			switch ( CurrentSettings.preset ) {
				case 'user':	case 'page':	case 'custom':
					break;
				default: //This should never occur.
					CurrentSettings.preset = 'page';
			}

			mozileSetPreset( CurrentSettings.preset );
			mozileApplyPresets( CurrentSettings.preset );	

		}
		else {	//Not currently implemented...because there must be a target for save button to work... 
			mozileSetPreset('user');
			mozileApplyPresets('user');
		}
		mozileSaveToBox();
		opener.mozileDebug(f,3,"Done Initializing");

	} catch(e) {
		opener.mozileDebug(f,3,"Error Initializing: "+e);
	}
}

function mozileSetLocks( configs ) {
	var i;

	if ( "savePresetDisallow" in configs ) {
		if ( configs.savePresetDisallow /*instanceof Array*/ ) { //Browser bug?
			for ( i=0; i<configs.savePresetDisallow.length; i++ ) {
				if ( configs.savePresetDisallow[i] != undefined ) {
					switch ( configs.savePresetDisallow[i] ) {
					case "user":
						document.getElementById('mozileUserPreset').setAttribute( "disabled", "true" );
						document.getElementById('mozileUserPreset').setAttribute( "collapsed", "true" );
						break;
					case "all":
						document.getElementById('mozilePresets').setAttribute( "collapsed", "true" );
						break;
					}
				}
			}
		}
	}

	if ( "saveMethodDisallow" in configs ) {
		if ( configs.saveMethodDisallow /*instanceof Array*/ ) {
			for ( i=0; i<configs.saveMethodDisallow.length; i++ ) {
				if ( configs.saveMethodDisallow[i] != undefined ) {
					switch ( configs.saveMethodDisallow[i] ) {
					case "display":
						document.getElementById('mozileSaveItemDisplay').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemDisplay').setAttribute( "collapsed", "true" );
						break;
					case "local":
						document.getElementById('mozileSaveItemLocal').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemLocal').setAttribute( "collapsed", "true" );
						break;
					case "post":
						document.getElementById('mozileSaveItemPost').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemPost').setAttribute( "collapsed", "true" );
						break;
					case "webdav":
						document.getElementById('mozileSaveItemWebdav').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemWebdav').setAttribute( "collapsed", "true" );
					}
				}
			}
		}
	}

	if ( "saveContentDisallow" in configs ) {
		if ( configs.saveContentDisallow /*instanceof Array*/ ) {
			for ( i=0; i<configs.saveContentDisallow.length; i++ ) {
				if ( configs.saveContentDisallow[i] != undefined ) {
					switch ( configs.saveContentDisallow[i] ) {
					case "page":
						document.getElementById('mozileSaveItemPage').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemPage').setAttribute( "collapsed", "true" );
						break;
					case "current":
						document.getElementById('mozileSaveItemCurrent').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemCurrent').setAttribute( "collapsed", "true" );
						break;
					case "current-ns":
						document.getElementById('mozileSaveItemCurrentXML').setAttribute( "disabled", "true" );
						document.getElementById('mozileSaveItemCurrentXML').setAttribute( "collapsed", "true" );
					}
				}
			}
		}
	}

	if ( "httpSavePathModify" in configs ) {
		if ( typeof (configs.httpSavePathModify) == "string" ) {
			if ( configs.httpSavePathModify == "false" ) {
				document.getElementById('mozileSaveTo').setAttribute( "readonly", "true" );
			}
		}
	}

}

	// Called when the user clicks "OK"
function mozileAccept() {
	var	f =	["save.js","mozileAccept"];
	opener.mozileDebug(f,2,"Accepting...");
	try {
		// store the current settings
		var	_mozileTarget = opener.mozileGetCurrentTarget();
		var mcc = _mozileTarget.document.MOZILE_CURRENT_CONFIG
  	mcc.preset = document.getElementById('mozileSavePresets').value;
  	mcc.saveContent = document.getElementById('mozileSaveContent').value;
  	mcc.saveMethod = document.getElementById('mozileSaveMethod').value;
  	mcc.httpSavePath = document.getElementById('mozileSaveTo').value;
		//and store the custom settings
		_mozileTarget.document.MOZILE_CUSTOM_CONFIG = CustomPresets;
		//Save...
		opener.mozileSave();
		opener.mozileDebug(f,2,"Accepted!");
	} catch(e) {
		opener.mozileDebug(f,2,"Save Error: "+e);
	}
}


function getSaveContentIndex( s ) {
  switch ( s ) {
		case "current-ns":
			return MOZILE_SAVE_CONTENT_CURRENT_NS;
		case "current":
			return MOZILE_SAVE_CONTENT_CURRENT;
		default: //case "page":
			return MOZILE_SAVE_CONTENT_PAGE;
	}
}

function getSaveMethodIndex( s ) {
  switch ( s ) {
		case "local":
			return MOZILE_SAVE_METHOD_LOCAL;
		case "post":
			return MOZILE_SAVE_METHOD_POST;
		case "webdav":
			return MOZILE_SAVE_METHOD_WEBDAV;
		default:
			return MOZILE_SAVE_METHOD_DISPLAY;
	}
}

	// Store the User Preset
function mozileStorePreset(node) {
	var	f =	["save.js","mozileStorePresets"];
	opener.mozileDebug(f,3,"Storing...");
	try{
		// Set local copy
  	UserPresets.saveContent = document.getElementById('mozileSaveContent').value;
  	UserPresets.saveMethod = document.getElementById('mozileSaveMethod').value;
  	UserPresets.httpSavePath = document.getElementById('mozileSaveTo').value;

  	mozileSetPreset("user");
  
  	// Store to the Mozilla preferences
  	netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');

  	_mozilePrefs.setCharPref("mozile.saveContentString", UserPresets.saveContent);
  	_mozilePrefs.setCharPref("mozile.saveMethodString", UserPresets.saveMethod);
  	_mozilePrefs.setCharPref("mozile.saveHttpPathString", UserPresets.httpSavePath);
  	
  	opener.mozileDebug(f,3,"Stored!");
	
	} catch(e) {
		opener.mozileDebug(f,2,"Store Error: "+e);
	}
}


	//When a Preset value is chosen, do some work
function mozilePreset(node)	{
	mozileApplyPresets(node.value);
	CurrentSettings.preset = node.value;
	mozileSaveToBox();
}

	// Change all of the form values to match the chosen Preset
function mozileApplyPresets(preset)	{
	var	presetObj	= new Object();
	switch(preset) {
		case "custom":
			presetObj = CustomPresets;
			break;
		case "user":
			presetObj = UserPresets;
			break;
		default: //case "page":
			presetObj = PagePresets;
			break;
	}
	document.getElementById('mozileSaveContent').selectedIndex = getSaveContentIndex( presetObj.saveContent );
	document.getElementById('mozileSaveMethod').selectedIndex = getSaveMethodIndex( presetObj.saveMethod );
	document.getElementById('mozileSaveTo').value =	presetObj.httpSavePath;
}

	// Decide whether or not to show the "Save To" field
function mozileSaveToBox() {
	var	box	= document.getElementById('mozileSaveToBox');
	var	saveMethod = document.getElementById('mozileSaveMethod').value;
	if (saveMethod == 'post') {
		box.collapsed=false;
	} else {
		box.collapsed=true;
	}
	self.sizeToContent();
}

	// When the content menu changes, just change the Preset menu to "Custom"
function mozileSaveContent(node) {
	mozileSetPreset('custom');
	mozileSetCustom();
}

	// When the method menu changes, change the Preset menu to "Custom", and show or hide the Save To field
function mozileSaveMethod(node)	{
	mozileSetPreset('custom');
	mozileSetCustom();
	mozileSaveToBox();
}

	// When the Save To file changes, change the Preset menu to "Custom".
function mozileSaveTo(node)	{
	mozileSetPreset('custom');
	mozileSetCustom();
}

	// Set the Preset menu to the given value
function mozileSetPreset(value)	{
	var p;
	if ( (value == 'page') || (value == MOZILE_SAVE_PRESET_PAGE) ) {
		p=MOZILE_SAVE_PRESET_PAGE;
	}
	else if ( (value == 'user') || (value == MOZILE_SAVE_PRESET_USER) ) {
		p=MOZILE_SAVE_PRESET_USER;
	}
	else {
		p=MOZILE_SAVE_PRESET_CUSTOM;
	}
	document.getElementById('mozileSavePresets').selectedIndex = p;
}

// If anything changes, store the dialog box values as the CustomPresets.
function mozileSetCustom() {
	try {
		var customMI = document.getElementById('mozileCustomPreset');
		if ( customMI.getAttribute( "disabled" ) == "true" )
			customMI.setAttribute( "disabled", "false" );
  	CustomPresets.saveContent = document.getElementById('mozileSaveContent').value;
  	CustomPresets.saveMethod = document.getElementById('mozileSaveMethod').value;
  	CustomPresets.httpSavePath = document.getElementById('mozileSaveTo').value;
	} catch (e) {
	
	}
}
